%
% Flash PT:
% 
% Ref: Henley e Seader 
%      pag 274

clear all
close all
warning off
clc

%Valores especificados:
Tfvetor=150:1:150;  % temperatura de flash (Farenheit)
Pf=205;  % pressao de flash (psia)

F=100;   % vazao de alimentacao (kgmole/hr)

z1=0.15;  % composicao da alimentacao etano
z2=0.35;  % composicao da alimentacao propano
z3=0.30;  % composicao da alimentacao butano



% 1)
z4=1-z1-z2-z3;  %composicao da alimentacao pentano



% Inicializando as variaveis:
Vvetor=[];
Fvetor=[];
Lvetor=[];
Xvetor=[];
Yvetor=[];
i=1;


% Loop para cada temperatura de flash
while (i<=length(Tfvetor)),
    
   Tf=Tfvetor(i);
       
       
	% Assumindo valores de k(t,p):
	
	% Pela Equacao de Antoine (eq 4-69, pag 159):
	% (valores de Pc do apendice 1, parte A, pag 715)
	% (valores de A1, A2, A3 do apendice 1, parte B, pag 720)
    % (temperatura em Farenheit)
    % (pressao em psia)
	A1=5.383894   ; A2=2847.921    ; A3=434.898    ; Pc=709.8  ; T=Tf;  %Substancia 48 (etano)
	divisao=exp( A1 - ( A2/(T+A3)  )  );
	Ps1=Pc*divisao;
	
	A1=5.353418   ; A2=3371.084    ; A3=414.488    ; Pc=617.4  ; T=Tf;  %Substancia 64 (propano)
	divisao=exp( A1 - ( A2/(T+A3)  )  );
	Ps2=Pc*divisao;
	
	A1= 5.741624   ; A2=4126.385    ; A3=409.5179   ; Pc=550.7  ; T=Tf;   %Substancia 87 (butano)
	divisao=exp( A1 - ( A2/(T+A3)  )  );
	Ps3=Pc*divisao;
	
	A1=5.853654   ; A2=4598.287    ; A3=394.4148    ; Pc=489.5  ; T=Tf;    %Substancia 104 (pentano)
	divisao=exp( A1 - ( A2/(T+A3)  )  );
	Ps4=Pc*divisao;
	
	
	% Pela Lei de Raoult (eq 4-75, pag 161):
	P=Pf;
	k1=Ps1/P;
	k2=Ps2/P;
	k3=Ps3/P;
	k4=Ps4/P;
	
	
	% Calculo de fi:
	pars=[z1 z2 z3 z4 k1 k2 k3 k4];
	% resolvendo por fzero:
	fi = fzero('funcaoex1',0.5,[],pars);
	
	
    V= F* fi;

    
	
	x1= z1/(1+(fi*(k1-1)));
	x2= z2/(1+(fi*(k2-1)));
	x3= z3/(1+(fi*(k3-1)));
	x4= z4/(1+(fi*(k4-1)));
	X=[x1 x2 x3 x4];
	Xvetor=[Xvetor;X];
	

	y1=(z1*k1)/(1+(fi*(k1-1)));
	y2=(z2*k2)/(1+(fi*(k2-1)));
	y3=(z3*k3)/(1+(fi*(k3-1)));
	y4=(z4*k4)/(1+(fi*(k4-1)));
	Y=[y1 y2 y3 y4];
	Yvetor=[Yvetor;Y];
	

	L=F-V;
    
    Fvetor=[Fvetor; F];
    Vvetor=[Vvetor; V];
    Lvetor=[Lvetor; L];
 
    % Incrementa o contador:
    i=i+1;



end


% Resultados:

Tfvetor

Xvetor

Yvetor

Lvetor

Vvetor

beta=Vvetor/(Vvetor+Lvetor)

