%
% Flash PT (com calculo de calor):
% 
% Ref: Henley e Seader 
%      pag 274

clear all
close all
warning off
clc

%Valores especificados:
Tfvetor=70;  % temperatura de flash (Farenheit)
Pf=30;  % pressao de flash (psia)

F=100;     % vazao de alimentacao (kgmole/hr)
Talim=100; % temperatura de alimentacao (Farenheit)
Palim=200; % pressao de alimentacao (psia)

z1=0.35;  % composicao da alimentacao C3H8
z2=0.25;  % composicao da alimentacao C4H10
z3=0.40;  % composicao da alimentacao C5H12



% Outros dados:
cpliq1=25.3; %C3H8
cpliq2=31.9; %C4H10
cpliq3=36.9; %C5H12

cpvap1=17.4; %C3H8
cpvap2=23.1; %C4H10
cpvap3=28.5; %C5H12

deltaHvap1=3600; %C3H8
deltaHvap2=5025; %C4H10
deltaHvap3=5870; %C5H12



% Conversao de Farenheit para Celsius:
TalimC=(Talim-32)/1.8;

% Calculo da H da alimentacao:
deltaT=TalimC-25;
Halim=z1*cpliq1*deltaT + ...
      z2*cpliq2*deltaT + ...
      z3*cpliq3*deltaT;
  


% Inicializando as variaveis:
Vvetor=[];
Fvetor=[];
Lvetor=[];
Xvetor=[];
Yvetor=[];
i=1;


% Loop para cada temperatura de flash
while (i<=length(Tfvetor)),
    
   Tf=Tfvetor(i);
       
       
	% Assumindo valores de k(t,p):
	
	% Pela Equacao de Antoine (eq 4-69, pag 159):
	% (valores de Pc do apendice 1, parte A, pag 715)
	% (valores de A1, A2, A3 do apendice 1, parte B, pag 720)
    % (temperatura em Farenheit)
    % (pressao em psia)
    
    A1=5.353418   ; A2=3371.084    ; A3=414.488    ; Pc= 617.4 ; T=Tf;  %Substancia 64 C3H8
	divisao=exp( A1 - ( A2/(T+A3)  )  );
	Ps1=Pc*divisao;
	
	A1=5.741624   ; A2=4126.385    ; A3=409.5179    ; Pc= 550.7  ; T=Tf;  %Substancia 87 C4H10
	divisao=exp( A1 - ( A2/(T+A3)  )  );
	Ps2=Pc*divisao;
	
	A1= 5.853654   ; A2=4598.287    ; A3=394.4148   ; Pc= 489.5 ; T=Tf;   %Substancia 104 C5H12
	divisao=exp( A1 - ( A2/(T+A3)  )  );
	Ps3=Pc*divisao;

	
	
	% Pela Lei de Raoult (eq 4-75, pag 161):
	P=Pf;
	k1=Ps1/P;
	k2=Ps2/P;
	k3=Ps3/P;
	
	
	% Calculo de fi:
	pars=[z1 z2 z3 k1 k2 k3];
	% resolvendo por fzero:
	fi = fzero('funcaoexerc3',0.5,[],pars);
	
	
    V= F* fi;

    
	
	x1= z1/(1+(fi*(k1-1)));
	x2= z2/(1+(fi*(k2-1)));
	x3= z3/(1+(fi*(k3-1)));
	X=[x1 x2 x3];
	Xvetor=[Xvetor;X];
	

	y1=(z1*k1)/(1+(fi*(k1-1)));
	y2=(z2*k2)/(1+(fi*(k2-1)));
	y3=(z3*k3)/(1+(fi*(k3-1)));
	Y=[y1 y2 y3];
	Yvetor=[Yvetor;Y];
	

	L=F-V;
    
    Fvetor=[Fvetor; F];
    Vvetor=[Vvetor; V];
    Lvetor=[Lvetor; L];
 
    % Incrementa o contador:
    i=i+1;



end




% Conversao de Farenheit para Celsius:
TfC=(Tf-32)/1.8;

% Calculo da H da saida liquida:
deltaT=TfC-25;
Hliquid=x1*cpliq1*deltaT + ...
        x2*cpliq2*deltaT + ...
        x3*cpliq3*deltaT;
  

% Calculo da H da saida vapor:
deltaT=TfC-25;
Hvap=y1*cpvap1*deltaT + ...
        y2*cpvap2*deltaT + ...
        y3*cpvap3*deltaT + ...
        y1*deltaHvap1+...
        y2*deltaHvap2+...
        y3*deltaHvap3;

% Calor do flash PT:
Q=(L*Hliquid + V*Hvap)-(F*Halim);



% Resultados:

Tfvetor

Xvetor

Yvetor

Lvetor

Vvetor

beta=Vvetor/(Vvetor+Lvetor)

Q